<?php
/*
 * Add Javascripts
 */
// Loads to posts screen
add_action( 'load-post.php', 'tbp_dupexam_load_js' );
add_action( 'load-post-new.php', 'tbp_dupexam_load_js' );
 
// Enqueues the needed javascripts
function tbp_dupexam_load_js() {
	//Grab plugin url defined in duplicate-examiner.php
	global $plugin_url;
	//Post id
	if ( isset( $_GET['post'] ) ) {
		$post_id = intval( $_GET['post'] );
	}
	
	//Enqueue script
	wp_enqueue_style( 'tbp_dupexam_styles', $plugin_url.'css/styles.css' );
	wp_enqueue_script( 'tbp_dupexam_copyjs', $plugin_url.'js/copy.js', array('jquery') );
	wp_enqueue_script( 'tbp_dupexam_diffjs', $plugin_url.'js/diff.js', array('jquery') );
	$params = array(
		'post_id' => $post_id
	);
	wp_localize_script( 'tbp_dupexam_diffjs', 'tbp_dupexam_diffjs_params', $params );
}

/*
 * Meta box to save original article
 */
//hook to add a meta box
add_action( 'add_meta_boxes', 'tbp_dupexam_original_mbe' );

function tbp_dupexam_original_mbe() {

	//create a custom meta box
	add_meta_box( 'tbp-dupexam-original', 'Duplicate Examiner', 'tbp_dupexam_original_mbe_function', 'post', 'normal', 'high' );

}

function tbp_dupexam_original_mbe_function( $post ) {
	//retrieve the meta data values if they exist
	$tbp_dupexam_mbe_content = get_post_meta( $post->ID, '_tbp_dupexam_mbe_content', true );

	?>
	<p><a id="tbp-viewchanges" href="#" class="button-highlighted">Click to view changes</a></p>
	<div id="tbp-dupexam-viewchanges">
	</div>
	<p>Check this box to copy content from post <input id="dupexamcopy" type="checkbox" name="tbp_dupexam_mbe_copy" /></p>
	<p>Original article</p>
	<textarea type="text" id="tbp_dupexam_mbe_content" name="tbp_dupexam_mbe_content" style="height: 4em; width: 98%"><?php echo stripslashes( $tbp_dupexam_mbe_content ); ?></textarea>
	<?php
}

//hook to save the meta box data
add_action( 'save_post', 'tbp_dupexam_mbe_save_meta' );

function tbp_dupexam_mbe_save_meta( $post_id ) {

	//verify the meta data is set
	if ( isset( $_POST['tbp_dupexam_mbe_content'] ) ) {
	
		//save the meta data
		update_post_meta( $post_id, '_tbp_dupexam_mbe_content', strip_tags( $_POST['tbp_dupexam_mbe_content'] ) );
	
	}
}

/*
 * Meta box to display the difference
 */
//hook to add a meta box
add_action( 'add_meta_boxes', 'tbp_dupexam_diffdisplay_mbe' );

function tbp_dupexam_diffdisplay_mbe() {

	//create a custom meta box
	add_meta_box( 'tbp-dupexam-diffdisplay', 'How Different Is My Content?', 'tbp_dupexam_diffdisplay_function', 'post', 'side', 'high' );

}

// Callback function to display difference
function tbp_dupexam_diffdisplay_function( $post ) {
	
	//Get data
	$tbp_dupexam_mbe_content = strip_stopwords(get_post_meta( $post->ID, '_tbp_dupexam_mbe_content', true ));
	$content = strip_stopwords(strip_tags( $post->post_content ));
	
	//Check for similarities without stop words
	similar_text($content, $tbp_dupexam_mbe_content, $percentMatch);
	$similar = round($percentMatch);
	
	// Percentage different
	$full = '100';
	$diff = 100 - $similar;
	
	
	?>
	<p><strong>Without stop words:</strong></p>
	<p>Your post is <span class="<?php if( $similar > '70' ) { ?>tbp-dupexam-bad<?php } else { ?>tbp-dupexam-good<?php } ?>"><?php echo $similar; ?>%</span> similar or <span class="<?php if( $diff < '30' ) { ?>tbp-dupexam-bad<?php } else { ?>tbp-dupexam-good<?php } ?>"><?php echo $diff; ?>%</span> different than the original</p>

<?php

	//Get data
	$tbp_dupexam_mbe_content = get_post_meta( $post->ID, '_tbp_dupexam_mbe_content', true );
	$content = strip_tags( $post->post_content );
	
	//Check for similarities without stop words
	similar_text($content, $tbp_dupexam_mbe_content, $percentMatch);
	$similar = round($percentMatch);
	
	// Percentage different
	$full = '100';
	$diff = 100 - $similar;

?>	
	<p><strong>With stop words:</strong></p>
	<p>Your post is <span class="<?php if( $similar > '70' ) { ?>tbp-dupexam-bad<?php } else { ?>tbp-dupexam-good<?php } ?>"><?php echo $similar; ?>%</span> similar or <span class="<?php if( $diff < '30' ) { ?>tbp-dupexam-bad<?php } else { ?>tbp-dupexam-good<?php } ?>"><?php echo $diff; ?>%</span> different than the original</p>
	<?php
}

// Ajax call back to display content difference
add_action ( 'wp_ajax_sppdupexam_diffcheck', 'tbp_dupexam_diffaction_callback' );
function tbp_dupexam_diffaction_callback() {
	$postid = intval( $_POST['post_id'] );
	
	//Get data
	$tbp_dupexam_mbe_content = get_post_meta( $postid, '_tbp_dupexam_mbe_content', true );
	$oldcontent_noshortcodes = strip_shortcodes( $tbp_dupexam_mbe_content );
	
	$getcontent = query_posts( 'p='.$postid );
	$content = $getcontent[0];
	$post_content = strip_tags($content->post_content, '<p><br>');
	$newcontent_noshortcodes = strip_shortcodes( $post_content );
	
	/*
	// Remove the stop words
	$newcontent_nostopwords = strip_stopwords($newcontent_noshortcodes);
	$oldcontent_nostopwords = strip_stopwords($oldcontent_noshortcodes);
	*/
	
	// Diff
	require ('simplediff.php');	
	// Show diff
	//htmlDiff($tbp_dupexam_mbe_content, $post_content);
	htmlDiff($oldcontent_noshortcodes, $newcontent_noshortcodes);
	wp_reset_query();
	die();
}

// Initialize the default set of stopwords.
function setup_stopwords()
{
	$stopwords = get_option('stopwords');
	if (empty($stopwords))
	{
		$stopwords = file_get_contents(plugin_dir_path(__FILE__) . '/default_stopwords.txt');
		$stopwords = preg_split("~[\s,]+~", $stopwords);
		update_option('stopwords', implode(", ", $stopwords));
	}
}

// Remove stop words from the content
function strip_stopwords($content)
{
	$stopwords = get_option('stopwords');

	if ($stopwords == '')
		setup_stopwords();
	
	$stopwords =  preg_split("~[\s,]+~", $stopwords);
	if (is_array($stopwords))
	{
		foreach ($stopwords as $word)
		{
			$word = trim($word);
			if ($word == '')
				continue;
			$content = str_ireplace($word, '', $content);
		}
	}
	return trim($content);
}

// Administration Settings Form under Settings => Duplicate Examiner
function tbp_dupexam_admin_settings_form()
{
?>
<div class="wrap">
	<h2>Duplicate Examiner Options</h2>
	<form method="post" action="options.php">
		<?php settings_fields( 'tbp_dupexam_options' ); ?>
		
		<p>Enter a list of common words separated with a comma</p>
		<textarea rows="10" cols="80" name="stopwords"><?php echo get_option('stopwords'); ?></textarea>
		
		<p class="submit"><input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" /></p>		
		
	</form>
</div>
<?php
}

?>